import os
import sys


project = 'EasyProcess'
author = 'ponty'
copyright = '2011, ponty'

__version__ = None
exec(open(os.path.join('..', project.lower(), 'about.py')).read())
release = __version__

# logging.basicConfig(level=logging.DEBUG)
sys.path.insert(0, os.path.abspath('..'))

# Extension
extensions = [
    # -*-Extensions: -*-
    'sphinx.ext.autodoc',
    #     'sphinxcontrib.programoutput',
    #     'sphinxcontrib.programscreenshot',
    #     'sphinx.ext.graphviz',
    #     'sphinxcontrib.autorun',
    #'sphinx.ext.autosummary',
    'sphinx.ext.intersphinx',
]
intersphinx_mapping = {'python': ('http://docs.python.org/', None)}

# Source
master_doc = 'index'
templates_path = ['_templates']
source_suffix = '.rst'
exclude_trees = []
pygments_style = 'sphinx'

# html build settings
html_theme = 'default'
html_static_path = ['_static']

# htmlhelp settings
htmlhelp_basename = '%sdoc' % project

# latex build settings
latex_documents = [
    ('index', '%s.tex' % project, u'%s Documentation' % project,
     author, 'manual'),
]

# remove blank pages from pdf
# http://groups.google.com/group/sphinx-
# dev/browse_thread/thread/92e19267d095412d/d60dcba483c6b13d
latex_font_size = '10pt,oneside'

latex_elements = dict(
    papersize='a4paper',
)



import logging
import shlex
import sys
import unicodedata

log = logging.getLogger(__name__)

PY3 = sys.version_info[0] >= 3

if PY3:
    string_types = str,
else:
    string_types = basestring,


class EasyProcessUnicodeError(Exception):
    pass


def split_command(cmd, posix=None):
    '''
     - cmd is string list -> nothing to do
     - cmd is string -> split it using shlex

    :param cmd: string ('ls -l') or list of strings (['ls','-l'])
    :rtype: string list
    '''
    if not isinstance(cmd, string_types):
        # cmd is string list
        pass
    else:
        if not PY3:
            # cmd is string
            # The shlex module currently does not support Unicode input (in
            # 2.x)!
            if isinstance(cmd, unicode):
                try:
                    cmd = unicodedata.normalize(
                        'NFKD', cmd).encode('ascii', 'strict')
                except UnicodeEncodeError:
                    raise EasyProcessUnicodeError('unicode command "%s" can not be processed.' % cmd +
                                                  'Use string list instead of string')
                log.debug('unicode is normalized')
        if posix is None:
            posix = 'win' not in sys.platform
        cmd = shlex.split(cmd, posix=posix)
    return cmd


def uniencode(s):
    if PY3:
        pass
#        s=s.encode()
    else:
        if isinstance(s, unicode):
            s = s.encode('utf-8')
    return s


def unidecode(s):
    if PY3:
        s = s.decode('utf-8', 'ignore')
    else:
        if isinstance(s, str):
            s = s.decode('utf-8', 'ignore')
    return s



from easyprocess import EasyProcess
import logging

# turn on logging
logging.basicConfig(level=logging.DEBUG)

EasyProcess('python --version').call()
EasyProcess('ping localhost').start().sleep(1).stop()
EasyProcess('python --version').check()
try:
    EasyProcess('bad_command').check()
except Exception as detail:
    print detail

try:
    EasyProcess('sh -c bad_command').check()
except Exception as detail:
    print detail



from easyprocess import EasyProcess

print(
    '-- Run program, wait for it to complete, get stdout (command is string):')
s = EasyProcess('python -c "print 3"').call().stdout
print(s)

print('-- Run program, wait for it to complete, get stdout (command is list):')
s = EasyProcess(['python', '-c', 'print 3']).call().stdout
print(s)

print('-- Run program, wait for it to complete, get stderr:')
s = EasyProcess('python --version').call().stderr
print(s)

print('-- Run program, wait for it to complete, get return code:')
s = EasyProcess('python --version').call().return_code
print(s)

print('-- Run program, wait 1 second, stop it, get stdout:')
s = EasyProcess('ping localhost').start().sleep(1).stop().stdout
print(s)



from setuptools import setup
import sys
import os

if os.environ.get('distutils_issue8876_workaround_enabled', False):
    # sdist_hack: Remove reference to os.link to disable using hardlinks when
    #             building setup.py's sdist target.  This is done because
    #             VirtualBox VMs shared filesystems don't support hardlinks.
    del os.link

NAME = 'easyprocess'
PYPI_NAME = 'EasyProcess'
URL = 'https://github.com/ponty/easyprocess'
DESCRIPTION = 'Easy to use python subprocess interface.'
PACKAGES = [NAME,
            NAME + '.examples',
            ]

# get __version__
__version__ = None
exec(open(os.path.join(NAME, 'about.py')).read())
VERSION = __version__

extra = {}
if sys.version_info >= (3,):
    extra['use_2to3'] = True

classifiers = [
    # Get more strings from
    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    'License :: OSI Approved :: BSD License',
    'Natural Language :: English',
    'Operating System :: OS Independent',

    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
]


setup(
    name=PYPI_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=open('README.rst', 'r').read(),
    classifiers=classifiers,
    keywords='subprocess interface',
    author='ponty',
    # author_email='',
    url=URL,
    license='BSD',
    packages=PACKAGES,
    **extra
)
